summaryrefslogtreecommitdiffstats
path: root/kopete/libkopete/kopeteproperties.h
diff options
context:
space:
mode:
authortpearson <tpearson@283d02a7-25f6-0310-bc7c-ecb5cbfe19da>2011-06-22 00:30:31 +0000
committertpearson <tpearson@283d02a7-25f6-0310-bc7c-ecb5cbfe19da>2011-06-22 00:30:31 +0000
commit69cac65817d949cda2672ec4f0aa73d5e66a0ba1 (patch)
tree073fde0496ea90eb5bf5cffe66a8da43a9f55fbc /kopete/libkopete/kopeteproperties.h
parent3467e6464beac3a162839bf7078e22e3a74d73e7 (diff)
downloadtdenetwork-69cac65817d949cda2672ec4f0aa73d5e66a0ba1.tar.gz
tdenetwork-69cac65817d949cda2672ec4f0aa73d5e66a0ba1.zip
TQt4 port kdenetwork
This enables compilation under both Qt3 and Qt4 git-svn-id: svn://anonsvn.kde.org/home/kde/branches/trinity/kdenetwork@1237912 283d02a7-25f6-0310-bc7c-ecb5cbfe19da
Diffstat (limited to 'kopete/libkopete/kopeteproperties.h')
-rw-r--r--kopete/libkopete/kopeteproperties.h12
1 files changed, 6 insertions, 6 deletions
diff --git a/kopete/libkopete/kopeteproperties.h b/kopete/libkopete/kopeteproperties.h
index e40a9280..a73a10c7 100644
--- a/kopete/libkopete/kopeteproperties.h
+++ b/kopete/libkopete/kopeteproperties.h
@@ -89,11 +89,11 @@ class Property : public PropertyBase<Parent>
{
public:
/**
* Returns the value of this property in the object @p parent.
*/
- virtual Type get( const Parent *parent ) const = 0;
+ virtual Type get( const Parent *tqparent ) const = 0;
/**
* Sets the value of this property in the object @p parent.
*/
virtual void set( Parent *, const Type & ) const = 0;
};
@@ -101,7 +101,7 @@ public:
/**
* @brief Base class for property data objects
*
* Some property objects want to store property-specific data in their parent objects.
* To support that, subclasses of this class are permitted to be stored. Once passed
* to the @ref PropertyStorage object via @ref PropertyStorage::setCustomPropertyData,
* the @ref PropertyStorage object owns the PropertyData, and will delete it when it
@@ -137,7 +137,7 @@ public:
* name their custom data differently. Names are bound by the same rules as are laid out
* for naming properties in PropertyBase<Parent>::name.
*/
- void setCustomPropertyData( const char *name, PropertyData *data ) const { _storage.replace( name, data ); }
+ void setCustomPropertyData( const char *name, PropertyData *data ) const { _storage.tqreplace( name, data ); }
/**
* Gets the stored property data with name @p name. Returns a null
@@ -309,7 +309,7 @@ void variantToXML(TQVariant v, TQDomElement &);
*/
/**
- * @brief Convenience implementation of XMLSerializable in terms of QVariants
+ * @brief Convenience implementation of XMLSerializable in terms of TQVariants
*
* This class provides XML serialization for data that can be stored in a TQVariant. You
* will need to multiply-inherit from this class and (usually indirectly) from @ref Property.
@@ -89,11 +89,11 @@ class Property : public PropertyBase<Parent>
public:
/**
- * Returns the value of this property in the object @p parent.
+ * Returns the value of this property in the object @p tqparent.
*/
@@ -89,11 +89,11 @@ class Property : public PropertyBase<Parent>
/**
- * Sets the value of this property in the object @p parent.
+ * Sets the value of this property in the object @p tqparent.
*/
virtual void set( Parent *, const Type & ) const = 0;
@@ -101,7 +101,7 @@ public:
* @brief Base class for property data objects
*
- * Some property objects want to store property-specific data in their parent objects.
+ * Some property objects want to store property-specific data in their tqparent objects.
* To support that, subclasses of this class are permitted to be stored. Once passed
* to the @ref PropertyStorage object via @ref PropertyStorage::setCustomPropertyData,